# ListConnectorResponse

Response object for connector list
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**connectors** | [**list[Connector]**](Connector.md) | List of connectors | 
**limit** | **int** | Limit on the number of rows in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


